@@ -1,7 +1,15 @@
+import importlib.metadata as importlib_metadata
+
+try:
+    __version__ = importlib_metadata.version(__package__ or __name__)
+except importlib_metadata.PackageNotFoundError:
+    pass
+
 import google.protobuf.message
 
 ProtobufMessage = google.protobuf.message.Message
 
+
 import nibiru.common  # noqa
 from nibiru.client import GrpcClient  # noqa
 from nibiru.common import Coin, Direction, PoolAsset, Side, TxConfig  # noqa
